@@ -1,15 +1,15 @@
 from .field_lists import (
     calculated_fields,
-    get_part_one_fields,
-    get_part_three_fbg_fields,
-    get_part_three_fields,
-    get_part_three_vitals_fields,
-    get_part_two_fields,
+    part_one_fields,
     part_three_comment_fields,
+    part_three_fbg_fields,
+    part_three_fields,
     part_three_glucose_fields,
     part_three_ogtt_fields,
     part_three_other_fields,
     part_three_pregnancy_fields,
+    part_three_vitals_fields,
+    part_two_fields,
 )
 from .screening_part_one_form import ScreeningPartOneForm
 from .screening_part_three_form import ScreeningPartThreeForm
