@@ -1,6 +1,6 @@
 from django.contrib import admin
-from edc_blood_results.admin import BloodResultsModelAdminMixin
-from edc_blood_results.fieldsets import BloodResultFieldset
+from edc_lab_results.admin import BloodResultsModelAdminMixin
+from edc_lab_results.fieldsets import BloodResultFieldset
 
 from ...admin_site import meta_subject_admin
 from ...forms import BloodResultsInsForm
