@@ -1,12 +1,12 @@
 from django import forms
 from edc_action_item.forms import ActionItemFormMixin
-from edc_blood_results.form_validator_mixins import (
-    BloodResultsFormValidatorMixin,
-    BloodResultsGluFormValidatorMixin,
-)
 from edc_crf.modelform_mixins import CrfModelFormMixin
 from edc_form_validators import FormValidator
 from edc_lab_panel.panels import blood_glucose_panel
+from edc_lab_results.form_validator_mixins import (
+    BloodResultsFormValidatorMixin,
+    BloodResultsGluFormValidatorMixin,
+)
 
 from ...models import BloodResultsGlu
 
